%define uname     vowpal_wabbit
%define major     0
%define libname   %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

Name:           vowpal-wabbit
Version:        8.2.1
Release:        %mkrel 3
Summary:        A fast and efficient machine learning system
License:        BSD
Group:          Sciences/Mathematics
Url:            http://hunch.net/~vw/
Source0:        http://github.com/JohnLangford/%{uname}/archive/%{version}/%{uname}-%{version}.tar.gz
Patch0:         vowpal_wabbit-8.2.1-linking.patch
# std::future does not exist on ARMv5
ExcludeArch:    armv5tl
BuildRequires:  gcc-c++
BuildRequires:  boost-devel
BuildRequires:  zlib-devel

%description
The Vowpal Wabbit (VW) project is a fast out-of-core learning system sponsored
by Microsoft Research and (previously) Yahoo! Research.

%package -n     %{libname}
Summary:        Main library for Vowpal Wabbit
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}

%description -n %{libname}
This package contains the library needed to run programs dynamically
linked with vowpal-wabbit.

%package -n     %{develname}
Summary:        Headers for developing programs that will use Vowpal Wabbit
Group:          Development/C
Requires:       %{name} = %{version}
Requires:       %{libname} = %{version}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
This package contains the headers that programmers will need to develop
applications which will use Vowpal Wabbit.

%prep
%setup -q -n %{uname}-%{version}
%autopatch -p1

%build
autoreconf -vfi
%configure2_5x \
	--disable-static
%make_build

%install
%make_install

# install the utl scripts
install -m 0755 utl/logistic %{buildroot}%{_bindir}/
install -m 0755 utl/vw-convergence %{buildroot}%{_bindir}/
install -m 0755 utl/vw-csv2bin %{buildroot}%{_bindir}/
install -m 0755 utl/vw-hypersearch %{buildroot}%{_bindir}/
install -m 0755 utl/vw-regr %{buildroot}%{_bindir}/
install -m 0755 utl/vw-top-errors %{buildroot}%{_bindir}/
install -m 0755 utl/vw-varinfo %{buildroot}%{_bindir}/
install -m 0755 utl/vw2csv %{buildroot}%{_bindir}/
mkdir -p %{buildroot}%{_datadir}/vowpalwabbit
install -m 0644 utl/vw-validate.html %{buildroot}%{_datadir}/vowpalwabbit/

# remove libtool files
find %{buildroot} -name '*.la' -delete

%files
%doc README.md AUTHORS
%license LICENSE
%{_bindir}/active_interactor
%{_bindir}/ezexample_predict
%{_bindir}/ezexample_train
%{_bindir}/library_example
%{_bindir}/logistic
%{_bindir}/spanning_tree
%{_bindir}/vw
%{_bindir}/vw-convergence
%{_bindir}/vw-csv2bin
%{_bindir}/vw-hypersearch
%{_bindir}/vw-regr
%{_bindir}/vw-top-errors
%{_bindir}/vw-varinfo
%{_bindir}/vw2csv
%dir %{_datadir}/vowpalwabbit
%{_datadir}/vowpalwabbit/vw-validate.html

%files -n %{libname}
%{_libdir}/liballreduce.so.%{major}{,.*}
%{_libdir}/libvw.so.%{major}{,.*}
%{_libdir}/libvw_c_wrapper.so.%{major}{,.*}

%files -n %{develname}
%dir %{_includedir}/vowpalwabbit
%{_includedir}/vowpalwabbit/*.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/libvw.pc
%{_libdir}/pkgconfig/libvw_c_wrapper.pc


%changelog
* Fri Sep 30 2016 wally <wally> 8.2.1-3.mga6
+ Revision: 1057904
- add patch to fix linking

* Mon Sep 26 2016 daviddavid <daviddavid> 8.2.1-2.mga6
+ Revision: 1057014
- disable build on ARMv5 as std::future does not exist

* Mon Sep 26 2016 daviddavid <daviddavid> 8.2.1-1.mga6
+ Revision: 1056759
- new version: 8.2.1
- update files list
- fix owner of data dir

* Sun Dec 27 2015 barjac <barjac> 7.3-10.mga6
+ Revision: 916058
- rebuild for boost-1.60.0

* Sat Sep 26 2015 daviddavid <daviddavid> 7.3-9.mga6
+ Revision: 883810
- rebuild for new boost 1.59.0

* Tue Aug 25 2015 cjw <cjw> 7.3-8.mga6
+ Revision: 869265
- rebuild with gcc 5

* Fri Jul 31 2015 sander85 <sander85> 7.3-7.mga6
+ Revision: 860052
- Rebuild for new boost

* Wed Oct 15 2014 umeabot <umeabot> 7.3-6.mga5
+ Revision: 750937
- Second Mageia 5 Mass Rebuild

* Fri Sep 26 2014 tv <tv> 7.3-5.mga5
+ Revision: 725278
- rebuild for bogus file deps

* Tue Sep 16 2014 umeabot <umeabot> 7.3-4.mga5
+ Revision: 690239
- Mageia 5 Mass Rebuild

* Sat Feb 08 2014 barjac <barjac> 7.3-3.mga5
+ Revision: 586839
- rebuild against boost-1.55

* Sat Oct 19 2013 umeabot <umeabot> 7.3-2.mga4
+ Revision: 533683
- Mageia 4 Mass Rebuild

* Tue Sep 03 2013 malo <malo> 7.3-1.mga4
+ Revision: 474822
- update to 7.3 and libification

* Wed Apr 10 2013 malo <malo> 7.2-2.mga4
+ Revision: 409436
- rebuild for boost 1.53

* Fri Apr 05 2013 malo <malo> 7.2-1.mga3
+ Revision: 408413
- update to 7.2, removed upstreamed patches

* Sat Jan 26 2013 malo <malo> 7.1-1.mga3
+ Revision: 392464
- fix build with upstream and linking patches
- patch for automake 1.13
- imported package vowpal-wabbit

